#!/usr/bin/perl -w
use strict;
use warnings;

my(@roots, %stddev, $table);

foreach(@ARGV) {
    my $root;
    if(m/^(.*)\.(.*)$/) {
	$root = $1;
    } else {
	$root = $_;
    }

    push @roots, $root;

    open(INPUT, $_) || die;

    my @fields;
    foreach my $field (<INPUT>) {
	@fields = split /\s/, $field;

	my($x, $y, $s);
	if(@fields == 3) {
	    ($x, $y, $s) = @fields;
	} elsif(@fields == 2) {
	    ($x, $y) = @fields;
	    $s = "NA";
	} else {
	    die;
	}

	$table->{$x}->{$root}->{"mean"} = $y;
	$table->{$x}->{$root}->{"sd"} = $s;
    }

    close(INPUT);
}

foreach my $root (@roots) {
    my $has_stddev = 0;

    foreach my $age (sort keys %$table) {
	if($table->{$age}->{$root}->{"sd"} &&
	   $table->{$age}->{$root}->{"sd"} ne "NA") {
	   $has_stddev = 1;
	}
    }

    $stddev{$root} = $has_stddev;
}

print "\\begin{tabular}{|c||";

for(my $i = 0; $i < @roots; ++$i) {
    if($stddev{$roots[$i]}) {
	print "r\@{ \$\\pm\$ }r|";
    } else {
	print "r|";
    }
}

print "} \\hline \n" .
      "Age";

foreach(@roots) {
    if($stddev{$_}) {
	print " & \\multicolumn{2}{|c|}{$_}";
    } else {
	print " & $_";
    }
}

print "\\\\ \\hline \\hline\n";

foreach my $age (sort keys %$table) {

    if($age == 11) {
	next;
    }

    printf "%.0f ", $age;

    foreach my $root (@roots) {
	if($stddev{$root}) {
	    if($table->{$age}->{$root}->{"mean"}) {
		if($table->{$age}->{$root}->{"sd"} &&
		   $table->{$age}->{$root}->{"sd"} ne "NA") {
		    print "& " . round($table->{$age}->{$root}->{"mean"}) .
			  "& " .  round($table->{$age}->{$root}->{"mean"},
				  $table->{$age}->{$root}->{"sd"}, 1) .  " ";
		} else {
		    print "& \\multicolumn{1}{r\@{ \$\\;\\;\\;\$ }}{" .
			  round($table->{$age}->{$root}->{"mean"}) .
			  "} & \\multicolumn{1}{r|}{} ";
		}
	    } else {
		print "& \\multicolumn{2}{r|}{} ";
	    }
	} else {
	    print "& ";
	    if($table->{$age}->{$root}->{"mean"}) {
		print round($table->{$age}->{$root}->{"mean"}) . " ";
	    }
	}
    }

    print "\\\\ \n";
}

print "\\hline\n" .
      "\\end{tabular}\n";

sub round {
    my($num, $sd, $switch) = @_;

    if($switch) {
	if($num >= 100) {
	    return sprintf "%.0f", $sd;
	} elsif($num >= 10) {
	    return sprintf "%.1f", $sd;
	} else {
	    return sprintf "%.2f", $sd;
	}
    } else {
	if($num >= 100) {
	    return sprintf "%.0f", $num;
	} elsif($num >= 10) {
	    return sprintf "%.1f", $num;
	} else {
	    return sprintf "%.2f", $num;
	}
    }
}
